# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/virtual_host_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import virtual_host_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/virtual_host_service.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:yandex/cloud/apploadbalancer/v1/virtual_host_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/apploadbalancer/v1/virtual_host.proto\x1a\x1dyandex/cloud/validation.proto\"|\n\x15GetVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x11virtual_host_name\x18\x02 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\"u\n\x17ListVirtualHostsRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"x\n\x18ListVirtualHostsResponse\x12\x43\n\rvirtual_hosts\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.VirtualHost\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe4\x02\n\x18\x43reateVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x11\n\tauthority\x18\x03 \x03(\t\x12\x36\n\x06routes\x18\x05 \x03(\x0b\x32&.yandex.cloud.apploadbalancer.v1.Route\x12S\n\x16modify_request_headers\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x07 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\"T\n\x19\x43reateVirtualHostMetadata\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"\x80\x03\n\x18UpdateVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x11\n\tauthority\x18\x04 \x03(\t\x12\x36\n\x06routes\x18\x06 \x03(\x0b\x32&.yandex.cloud.apploadbalancer.v1.Route\x12S\n\x16modify_request_headers\x18\x07 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x08 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\"N\n\x19UpdateVirtualHostMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"\x7f\n\x18\x44\x65leteVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x11virtual_host_name\x18\x02 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\"N\n\x19\x44\x65leteVirtualHostMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"m\n\x12RemoveRouteRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nroute_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"\\\n\x13RemoveRouteMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\x12\x12\n\nroute_name\x18\x03 \x01(\t\"\xa5\x02\n\x12UpdateRouteRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nroute_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12:\n\x04http\x18\x05 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.HttpRouteH\x00\x12:\n\x04grpc\x18\x06 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.GrpcRouteH\x00\x42\r\n\x05route\x12\x04\xc0\xc1\x31\x01\"\\\n\x13UpdateRouteMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\x12\x12\n\nroute_name\x18\x03 \x01(\t2\xe2\x0c\n\x12VirtualHostService\x12\xc6\x01\n\x03Get\x12\x36.yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest\x1a,.yandex.cloud.apploadbalancer.v1.VirtualHost\"Y\x82\xd3\xe4\x93\x02S\x12Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\x12\xc2\x01\n\x04List\x12\x38.yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest\x1a\x39.yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts\x12\xdc\x01\n\x06\x43reate\x12\x39.yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"t\x82\xd3\xe4\x93\x02\x42\"=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts:\x01*\xb2\xd2*(\n\x19\x43reateVirtualHostMetadata\x12\x0bVirtualHost\x12\xf1\x01\n\x06Update\x12\x39.yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\x82\xd3\xe4\x93\x02V2Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:\x01*\xb2\xd2*(\n\x19UpdateVirtualHostMetadata\x12\x0bVirtualHost\x12\xf8\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\x82\xd3\xe4\x93\x02S*Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\xb2\xd2*2\n\x19\x44\x65leteVirtualHostMetadata\x12\x15google.protobuf.Empty\x12\xf6\x01\n\x0bRemoveRoute\x12\x33.yandex.cloud.apploadbalancer.v1.RemoveRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02\x62\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:removeRoute:\x01*\xb2\xd2*\"\n\x13RemoveRouteMetadata\x12\x0bVirtualHost\x12\xf6\x01\n\x0bUpdateRoute\x12\x33.yandex.cloud.apploadbalancer.v1.UpdateRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02\x62\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:updateRoute:\x01*\xb2\xd2*\"\n\x13UpdateRouteMetadata\x12\x0bVirtualHostBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='GetVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=440,
)


_LISTVIRTUALHOSTSREQUEST = _descriptor.Descriptor(
  name='ListVirtualHostsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=559,
)


_LISTVIRTUALHOSTSRESPONSE = _descriptor.Descriptor(
  name='ListVirtualHostsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_hosts', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse.virtual_hosts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=681,
)


_CREATEVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='CreateVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.authority', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.routes', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_request_headers', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.modify_request_headers', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_response_headers', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.modify_response_headers', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=1040,
)


_CREATEVIRTUALHOSTMETADATA = _descriptor.Descriptor(
  name='CreateVirtualHostMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1126,
)


_UPDATEVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.authority', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.routes', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_request_headers', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.modify_request_headers', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_response_headers', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.modify_response_headers', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1513,
)


_UPDATEVIRTUALHOSTMETADATA = _descriptor.Descriptor(
  name='UpdateVirtualHostMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1593,
)


_DELETEVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1595,
  serialized_end=1722,
)


_DELETEVIRTUALHOSTMETADATA = _descriptor.Descriptor(
  name='DeleteVirtualHostMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1802,
)


_REMOVEROUTEREQUEST = _descriptor.Descriptor(
  name='RemoveRouteRequest',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1804,
  serialized_end=1913,
)


_REMOVEROUTEMETADATA = _descriptor.Descriptor(
  name='RemoveRouteMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1915,
  serialized_end=2007,
)


_UPDATEROUTEREQUEST = _descriptor.Descriptor(
  name='UpdateRouteRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.update_mask', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.http', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.grpc', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='route', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.route',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2010,
  serialized_end=2303,
)


_UPDATEROUTEMETADATA = _descriptor.Descriptor(
  name='UpdateRouteMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2305,
  serialized_end=2397,
)

_LISTVIRTUALHOSTSRESPONSE.fields_by_name['virtual_hosts'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._VIRTUALHOST
_CREATEVIRTUALHOSTREQUEST.fields_by_name['routes'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._ROUTE
_CREATEVIRTUALHOSTREQUEST.fields_by_name['modify_request_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_CREATEVIRTUALHOSTREQUEST.fields_by_name['modify_response_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['routes'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._ROUTE
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['modify_request_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['modify_response_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_UPDATEROUTEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEROUTEREQUEST.fields_by_name['http'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HTTPROUTE
_UPDATEROUTEREQUEST.fields_by_name['grpc'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._GRPCROUTE
_UPDATEROUTEREQUEST.oneofs_by_name['route'].fields.append(
  _UPDATEROUTEREQUEST.fields_by_name['http'])
_UPDATEROUTEREQUEST.fields_by_name['http'].containing_oneof = _UPDATEROUTEREQUEST.oneofs_by_name['route']
_UPDATEROUTEREQUEST.oneofs_by_name['route'].fields.append(
  _UPDATEROUTEREQUEST.fields_by_name['grpc'])
_UPDATEROUTEREQUEST.fields_by_name['grpc'].containing_oneof = _UPDATEROUTEREQUEST.oneofs_by_name['route']
DESCRIPTOR.message_types_by_name['GetVirtualHostRequest'] = _GETVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualHostsRequest'] = _LISTVIRTUALHOSTSREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualHostsResponse'] = _LISTVIRTUALHOSTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateVirtualHostRequest'] = _CREATEVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualHostMetadata'] = _CREATEVIRTUALHOSTMETADATA
DESCRIPTOR.message_types_by_name['UpdateVirtualHostRequest'] = _UPDATEVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualHostMetadata'] = _UPDATEVIRTUALHOSTMETADATA
DESCRIPTOR.message_types_by_name['DeleteVirtualHostRequest'] = _DELETEVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualHostMetadata'] = _DELETEVIRTUALHOSTMETADATA
DESCRIPTOR.message_types_by_name['RemoveRouteRequest'] = _REMOVEROUTEREQUEST
DESCRIPTOR.message_types_by_name['RemoveRouteMetadata'] = _REMOVEROUTEMETADATA
DESCRIPTOR.message_types_by_name['UpdateRouteRequest'] = _UPDATEROUTEREQUEST
DESCRIPTOR.message_types_by_name['UpdateRouteMetadata'] = _UPDATEROUTEMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetVirtualHostRequest = _reflection.GeneratedProtocolMessageType('GetVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest)
  })
_sym_db.RegisterMessage(GetVirtualHostRequest)

ListVirtualHostsRequest = _reflection.GeneratedProtocolMessageType('ListVirtualHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALHOSTSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest)
  })
_sym_db.RegisterMessage(ListVirtualHostsRequest)

ListVirtualHostsResponse = _reflection.GeneratedProtocolMessageType('ListVirtualHostsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALHOSTSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse)
  })
_sym_db.RegisterMessage(ListVirtualHostsResponse)

CreateVirtualHostRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest)
  })
_sym_db.RegisterMessage(CreateVirtualHostRequest)

CreateVirtualHostMetadata = _reflection.GeneratedProtocolMessageType('CreateVirtualHostMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALHOSTMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata)
  })
_sym_db.RegisterMessage(CreateVirtualHostMetadata)

UpdateVirtualHostRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualHostRequest)

UpdateVirtualHostMetadata = _reflection.GeneratedProtocolMessageType('UpdateVirtualHostMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALHOSTMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata)
  })
_sym_db.RegisterMessage(UpdateVirtualHostMetadata)

DeleteVirtualHostRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualHostRequest)

DeleteVirtualHostMetadata = _reflection.GeneratedProtocolMessageType('DeleteVirtualHostMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALHOSTMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata)
  })
_sym_db.RegisterMessage(DeleteVirtualHostMetadata)

RemoveRouteRequest = _reflection.GeneratedProtocolMessageType('RemoveRouteRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROUTEREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveRouteRequest)
  })
_sym_db.RegisterMessage(RemoveRouteRequest)

RemoveRouteMetadata = _reflection.GeneratedProtocolMessageType('RemoveRouteMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROUTEMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata)
  })
_sym_db.RegisterMessage(RemoveRouteMetadata)

UpdateRouteRequest = _reflection.GeneratedProtocolMessageType('UpdateRouteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROUTEREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateRouteRequest)
  })
_sym_db.RegisterMessage(UpdateRouteRequest)

UpdateRouteMetadata = _reflection.GeneratedProtocolMessageType('UpdateRouteMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROUTEMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata)
  })
_sym_db.RegisterMessage(UpdateRouteMetadata)


DESCRIPTOR._options = None
_GETVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_GETVIRTUALHOSTREQUEST.fields_by_name['virtual_host_name']._options = None
_LISTVIRTUALHOSTSREQUEST.fields_by_name['http_router_id']._options = None
_LISTVIRTUALHOSTSREQUEST.fields_by_name['page_size']._options = None
_LISTVIRTUALHOSTSREQUEST.fields_by_name['page_token']._options = None
_CREATEVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_CREATEVIRTUALHOSTREQUEST.fields_by_name['name']._options = None
_CREATEVIRTUALHOSTMETADATA.fields_by_name['http_router_id']._options = None
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['virtual_host_name']._options = None
_DELETEVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_DELETEVIRTUALHOSTREQUEST.fields_by_name['virtual_host_name']._options = None
_REMOVEROUTEREQUEST.fields_by_name['http_router_id']._options = None
_REMOVEROUTEREQUEST.fields_by_name['virtual_host_name']._options = None
_REMOVEROUTEREQUEST.fields_by_name['route_name']._options = None
_UPDATEROUTEREQUEST.oneofs_by_name['route']._options = None
_UPDATEROUTEREQUEST.fields_by_name['http_router_id']._options = None
_UPDATEROUTEREQUEST.fields_by_name['virtual_host_name']._options = None
_UPDATEROUTEREQUEST.fields_by_name['route_name']._options = None

_VIRTUALHOSTSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualHostService',
  full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2400,
  serialized_end=4034,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Get',
    index=0,
    containing_service=None,
    input_type=_GETVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._VIRTUALHOST,
    serialized_options=b'\202\323\344\223\002S\022Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.List',
    index=1,
    containing_service=None,
    input_type=_LISTVIRTUALHOSTSREQUEST,
    output_type=_LISTVIRTUALHOSTSRESPONSE,
    serialized_options=b'\202\323\344\223\002?\022=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002B\"=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts:\001*\262\322*(\n\031CreateVirtualHostMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002V2Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:\001*\262\322*(\n\031UpdateVirtualHostMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002S*Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\262\322*2\n\031DeleteVirtualHostMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveRoute',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.RemoveRoute',
    index=5,
    containing_service=None,
    input_type=_REMOVEROUTEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002b\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:removeRoute:\001*\262\322*\"\n\023RemoveRouteMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRoute',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.UpdateRoute',
    index=6,
    containing_service=None,
    input_type=_UPDATEROUTEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002b\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:updateRoute:\001*\262\322*\"\n\023UpdateRouteMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALHOSTSERVICE)

DESCRIPTOR.services_by_name['VirtualHostService'] = _VIRTUALHOSTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.oauth import claims_pb2 as yandex_dot_cloud_dot_oauth_dot_claims__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/user_service.proto',
  package='yandex.cloud.organizationmanager.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/organizationmanager/v1/user_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x1fyandex/cloud/oauth/claims.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"y\n\x12ListMembersRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xd7\x01\n\x13ListMembersResponse\x12X\n\x05users\x18\x01 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.ListMembersResponse.OrganizationUser\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1aM\n\x10OrganizationUser\x12\x39\n\x0esubject_claims\x18\x01 \x01(\x0b\x32!.yandex.cloud.oauth.SubjectClaims\"^\n\x17\x44\x65leteMembershipRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nsubject_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"c\n\x18\x44\x65leteMembershipMetadata\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"c\n\x18\x44\x65leteMembershipResponse\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xdc\x03\n\x0bUserService\x12\xc8\x01\n\x0bListMembers\x12\x37.yandex.cloud.organizationmanager.v1.ListMembersRequest\x1a\x38.yandex.cloud.organizationmanager.v1.ListMembersResponse\"F\x82\xd3\xe4\x93\x02@\x12>/organization-manager/v1/organizations/{organization_id}/users\x12\x81\x02\n\x10\x44\x65leteMembership\x12<.yandex.cloud.organizationmanager.v1.DeleteMembershipRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\x82\xd3\xe4\x93\x02M*K/organization-manager/v1/organizations/{organization_id}/users/{subject_id}\xb2\xd2*4\n\x18\x44\x65leteMembershipMetadata\x12\x18\x44\x65leteMembershipResponseB\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_oauth_dot_claims__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_LISTMEMBERSREQUEST = _descriptor.Descriptor(
  name='ListMembersRequest',
  full_name='yandex.cloud.organizationmanager.v1.ListMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.ListMembersRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.ListMembersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.ListMembersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=384,
)


_LISTMEMBERSRESPONSE_ORGANIZATIONUSER = _descriptor.Descriptor(
  name='OrganizationUser',
  full_name='yandex.cloud.organizationmanager.v1.ListMembersResponse.OrganizationUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject_claims', full_name='yandex.cloud.organizationmanager.v1.ListMembersResponse.OrganizationUser.subject_claims', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=602,
)

_LISTMEMBERSRESPONSE = _descriptor.Descriptor(
  name='ListMembersResponse',
  full_name='yandex.cloud.organizationmanager.v1.ListMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='yandex.cloud.organizationmanager.v1.ListMembersResponse.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.ListMembersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMEMBERSRESPONSE_ORGANIZATIONUSER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=602,
)


_DELETEMEMBERSHIPREQUEST = _descriptor.Descriptor(
  name='DeleteMembershipRequest',
  full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipRequest.subject_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=698,
)


_DELETEMEMBERSHIPMETADATA = _descriptor.Descriptor(
  name='DeleteMembershipMetadata',
  full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipMetadata.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipMetadata.subject_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=799,
)


_DELETEMEMBERSHIPRESPONSE = _descriptor.Descriptor(
  name='DeleteMembershipResponse',
  full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipResponse.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='yandex.cloud.organizationmanager.v1.DeleteMembershipResponse.subject_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=900,
)

_LISTMEMBERSRESPONSE_ORGANIZATIONUSER.fields_by_name['subject_claims'].message_type = yandex_dot_cloud_dot_oauth_dot_claims__pb2._SUBJECTCLAIMS
_LISTMEMBERSRESPONSE_ORGANIZATIONUSER.containing_type = _LISTMEMBERSRESPONSE
_LISTMEMBERSRESPONSE.fields_by_name['users'].message_type = _LISTMEMBERSRESPONSE_ORGANIZATIONUSER
DESCRIPTOR.message_types_by_name['ListMembersRequest'] = _LISTMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['ListMembersResponse'] = _LISTMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteMembershipRequest'] = _DELETEMEMBERSHIPREQUEST
DESCRIPTOR.message_types_by_name['DeleteMembershipMetadata'] = _DELETEMEMBERSHIPMETADATA
DESCRIPTOR.message_types_by_name['DeleteMembershipResponse'] = _DELETEMEMBERSHIPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListMembersRequest = _reflection.GeneratedProtocolMessageType('ListMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListMembersRequest)
  })
_sym_db.RegisterMessage(ListMembersRequest)

ListMembersResponse = _reflection.GeneratedProtocolMessageType('ListMembersResponse', (_message.Message,), {

  'OrganizationUser' : _reflection.GeneratedProtocolMessageType('OrganizationUser', (_message.Message,), {
    'DESCRIPTOR' : _LISTMEMBERSRESPONSE_ORGANIZATIONUSER,
    '__module__' : 'yandex.cloud.organizationmanager.v1.user_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListMembersResponse.OrganizationUser)
    })
  ,
  'DESCRIPTOR' : _LISTMEMBERSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListMembersResponse)
  })
_sym_db.RegisterMessage(ListMembersResponse)
_sym_db.RegisterMessage(ListMembersResponse.OrganizationUser)

DeleteMembershipRequest = _reflection.GeneratedProtocolMessageType('DeleteMembershipRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEMBERSHIPREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.DeleteMembershipRequest)
  })
_sym_db.RegisterMessage(DeleteMembershipRequest)

DeleteMembershipMetadata = _reflection.GeneratedProtocolMessageType('DeleteMembershipMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEMBERSHIPMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.DeleteMembershipMetadata)
  })
_sym_db.RegisterMessage(DeleteMembershipMetadata)

DeleteMembershipResponse = _reflection.GeneratedProtocolMessageType('DeleteMembershipResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEMBERSHIPRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.DeleteMembershipResponse)
  })
_sym_db.RegisterMessage(DeleteMembershipResponse)


DESCRIPTOR._options = None
_LISTMEMBERSREQUEST.fields_by_name['organization_id']._options = None
_LISTMEMBERSREQUEST.fields_by_name['page_size']._options = None
_LISTMEMBERSREQUEST.fields_by_name['page_token']._options = None
_DELETEMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
_DELETEMEMBERSHIPREQUEST.fields_by_name['subject_id']._options = None
_DELETEMEMBERSHIPMETADATA.fields_by_name['organization_id']._options = None
_DELETEMEMBERSHIPMETADATA.fields_by_name['subject_id']._options = None
_DELETEMEMBERSHIPRESPONSE.fields_by_name['organization_id']._options = None
_DELETEMEMBERSHIPRESPONSE.fields_by_name['subject_id']._options = None

_USERSERVICE = _descriptor.ServiceDescriptor(
  name='UserService',
  full_name='yandex.cloud.organizationmanager.v1.UserService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=903,
  serialized_end=1379,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='yandex.cloud.organizationmanager.v1.UserService.ListMembers',
    index=0,
    containing_service=None,
    input_type=_LISTMEMBERSREQUEST,
    output_type=_LISTMEMBERSRESPONSE,
    serialized_options=b'\202\323\344\223\002@\022>/organization-manager/v1/organizations/{organization_id}/users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMembership',
    full_name='yandex.cloud.organizationmanager.v1.UserService.DeleteMembership',
    index=1,
    containing_service=None,
    input_type=_DELETEMEMBERSHIPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002M*K/organization-manager/v1/organizations/{organization_id}/users/{subject_id}\262\322*4\n\030DeleteMembershipMetadata\022\030DeleteMembershipResponse',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERSERVICE)

DESCRIPTOR.services_by_name['UserService'] = _USERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/redis/v1/config/redis5_0.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/redis/v1/config/redis5_0.proto',
  package='yandex.cloud.mdb.redis.v1.config',
  syntax='proto3',
  serialized_options=b'\n$yandex.cloud.api.mdb.redis.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1/config;redis',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/mdb/redis/v1/config/redis5_0.proto\x12 yandex.cloud.mdb.redis.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x93\x05\n\x0eRedisConfig5_0\x12Z\n\x10maxmemory_policy\x18\x01 \x01(\x0e\x32@.yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.MaxmemoryPolicy\x12,\n\x07timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x08password\x18\x03 \x01(\tB&\xf2\xc7\x31\"[a-zA-Z0-9@=+?*.,!&#$^<>_-]{8,128}\x12\x36\n\tdatabases\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x45\n\x17slowlog_log_slower_than\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12=\n\x0fslowlog_max_len\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x38\n\x16notify_keyspace_events\x18\x07 \x01(\tB\x18\xf2\xc7\x31\x14[KEg$lshzxeAt]{0,12}\"\xc4\x01\n\x0fMaxmemoryPolicy\x12 \n\x1cMAXMEMORY_POLICY_UNSPECIFIED\x10\x00\x12\x10\n\x0cVOLATILE_LRU\x10\x01\x12\x0f\n\x0b\x41LLKEYS_LRU\x10\x02\x12\x10\n\x0cVOLATILE_LFU\x10\x03\x12\x0f\n\x0b\x41LLKEYS_LFU\x10\x04\x12\x13\n\x0fVOLATILE_RANDOM\x10\x05\x12\x12\n\x0e\x41LLKEYS_RANDOM\x10\x06\x12\x10\n\x0cVOLATILE_TTL\x10\x07\x12\x0e\n\nNOEVICTION\x10\x08\"\xf0\x01\n\x11RedisConfigSet5_0\x12J\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig5_0\x12\x45\n\x0buser_config\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig5_0\x12H\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig5_0Br\n$yandex.cloud.api.mdb.redis.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1/config;redisb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_REDISCONFIG5_0_MAXMEMORYPOLICY = _descriptor.EnumDescriptor(
  name='MaxmemoryPolicy',
  full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.MaxmemoryPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAXMEMORY_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOLATILE_LRU', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLKEYS_LRU', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOLATILE_LFU', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLKEYS_LFU', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOLATILE_RANDOM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLKEYS_RANDOM', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOLATILE_TTL', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOEVICTION', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=612,
  serialized_end=808,
)
_sym_db.RegisterEnumDescriptor(_REDISCONFIG5_0_MAXMEMORYPOLICY)


_REDISCONFIG5_0 = _descriptor.Descriptor(
  name='RedisConfig5_0',
  full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxmemory_policy', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.maxmemory_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"[a-zA-Z0-9@=+?*.,!&#$^<>_-]{8,128}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='databases', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.databases', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slowlog_log_slower_than', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.slowlog_log_slower_than', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slowlog_max_len', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.slowlog_max_len', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_keyspace_events', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfig5_0.notify_keyspace_events', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\024[KEg$lshzxeAt]{0,12}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REDISCONFIG5_0_MAXMEMORYPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=808,
)


_REDISCONFIGSET5_0 = _descriptor.Descriptor(
  name='RedisConfigSet5_0',
  full_name='yandex.cloud.mdb.redis.v1.config.RedisConfigSet5_0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfigSet5_0.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfigSet5_0.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.redis.v1.config.RedisConfigSet5_0.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=1051,
)

_REDISCONFIG5_0.fields_by_name['maxmemory_policy'].enum_type = _REDISCONFIG5_0_MAXMEMORYPOLICY
_REDISCONFIG5_0.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REDISCONFIG5_0.fields_by_name['databases'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REDISCONFIG5_0.fields_by_name['slowlog_log_slower_than'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REDISCONFIG5_0.fields_by_name['slowlog_max_len'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REDISCONFIG5_0_MAXMEMORYPOLICY.containing_type = _REDISCONFIG5_0
_REDISCONFIGSET5_0.fields_by_name['effective_config'].message_type = _REDISCONFIG5_0
_REDISCONFIGSET5_0.fields_by_name['user_config'].message_type = _REDISCONFIG5_0
_REDISCONFIGSET5_0.fields_by_name['default_config'].message_type = _REDISCONFIG5_0
DESCRIPTOR.message_types_by_name['RedisConfig5_0'] = _REDISCONFIG5_0
DESCRIPTOR.message_types_by_name['RedisConfigSet5_0'] = _REDISCONFIGSET5_0
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RedisConfig5_0 = _reflection.GeneratedProtocolMessageType('RedisConfig5_0', (_message.Message,), {
  'DESCRIPTOR' : _REDISCONFIG5_0,
  '__module__' : 'yandex.cloud.mdb.redis.v1.config.redis5_0_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.redis.v1.config.RedisConfig5_0)
  })
_sym_db.RegisterMessage(RedisConfig5_0)

RedisConfigSet5_0 = _reflection.GeneratedProtocolMessageType('RedisConfigSet5_0', (_message.Message,), {
  'DESCRIPTOR' : _REDISCONFIGSET5_0,
  '__module__' : 'yandex.cloud.mdb.redis.v1.config.redis5_0_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.redis.v1.config.RedisConfigSet5_0)
  })
_sym_db.RegisterMessage(RedisConfigSet5_0)


DESCRIPTOR._options = None
_REDISCONFIG5_0.fields_by_name['password']._options = None
_REDISCONFIG5_0.fields_by_name['databases']._options = None
_REDISCONFIG5_0.fields_by_name['slowlog_log_slower_than']._options = None
_REDISCONFIG5_0.fields_by_name['slowlog_max_len']._options = None
_REDISCONFIG5_0.fields_by_name['notify_keyspace_events']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/ml_model.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/clickhouse/v1/ml_model.proto',
  package='yandex.cloud.mdb.clickhouse.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/mdb/clickhouse/v1/ml_model.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\"s\n\x07MlModel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.yandex.cloud.mdb.clickhouse.v1.MlModelType\x12\x0b\n\x03uri\x18\x04 \x01(\t*H\n\x0bMlModelType\x12\x1d\n\x19ML_MODEL_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16ML_MODEL_TYPE_CATBOOST\x10\x01\x42s\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3'
)

_MLMODELTYPE = _descriptor.EnumDescriptor(
  name='MlModelType',
  full_name='yandex.cloud.mdb.clickhouse.v1.MlModelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ML_MODEL_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ML_MODEL_TYPE_CATBOOST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=198,
  serialized_end=270,
)
_sym_db.RegisterEnumDescriptor(_MLMODELTYPE)

MlModelType = enum_type_wrapper.EnumTypeWrapper(_MLMODELTYPE)
ML_MODEL_TYPE_UNSPECIFIED = 0
ML_MODEL_TYPE_CATBOOST = 1



_MLMODEL = _descriptor.Descriptor(
  name='MlModel',
  full_name='yandex.cloud.mdb.clickhouse.v1.MlModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.clickhouse.v1.MlModel.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.MlModel.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.mdb.clickhouse.v1.MlModel.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yandex.cloud.mdb.clickhouse.v1.MlModel.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=196,
)

_MLMODEL.fields_by_name['type'].enum_type = _MLMODELTYPE
DESCRIPTOR.message_types_by_name['MlModel'] = _MLMODEL
DESCRIPTOR.enum_types_by_name['MlModelType'] = _MLMODELTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MlModel = _reflection.GeneratedProtocolMessageType('MlModel', (_message.Message,), {
  'DESCRIPTOR' : _MLMODEL,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.ml_model_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.MlModel)
  })
_sym_db.RegisterMessage(MlModel)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages

packages = find_packages('.', include=['yandexcloud*', 'yandex*'])

setup(name='yandexcloud',
      version='0.108.0',
      description='The Yandex.Cloud official SDK',
      url='https://github.com/yandex-cloud/python-sdk',
      author='Yandex LLC',
      author_email='cloud@support.yandex.ru',
      license='MIT',
      install_requires=[
          'cryptography>=2.8',
          'grpcio>=1.38.1',
          'googleapis-common-protos>=1.53.0',
          'pyjwt>=1.7.1',
          'requests>=2.22.0',
          'six>=1.14.0',
      ],
      classifiers=[
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.7',
      ],
      tests_require=['pytest'],
      packages=packages,
      zip_safe=False)
